-- Reputation Reference window handler

import "Turbine.UI.Lotro"
import "Vinny.Common"

local labelFont = Turbine.UI.Lotro.Font.TrajanPro14
local foreColor = Turbine.UI.Color( 0.9, 0.9, 0 )
local backColor = Turbine.UI.Color( 0, 0, 0.1 )
local Button = Turbine.UI.Lotro.Button
local TextBox = Turbine.UI.TextBox
local Label = Turbine.UI.Label
local All,Select = "<All>","<All>"

RR_Window = class( Turbine.UI.Lotro.Window )

function RR_Window:AddField(control, text, pos, size)
	local field = control()
	field:SetParent( self )
	field:SetText( text )
	field:SetPosition( pos.x,pos.y )
	field:SetSize( size.x,size.y )
	if control==Button then return field end
	field:SetFont( labelFont )
	field:SetForeColor( foreColor )
	field:SetBackColor( backColor )
	field:SetTextAlignment( Turbine.UI.ContentAlignment.MiddleCenter )
	return field
end

function RR_Window:BuildMenu(list,button)
	local Menu = Turbine.UI.ContextMenu()
	local menuItems,Item = Menu:GetItems()
	local selected = button:GetText()
	for i,name in ipairs(list) do
        Item = Turbine.UI.MenuItem(name)
        if name==selected then Item:SetChecked(true) end
        Item.Click = function( sender,args )
            if selected == sender:GetText() then selected = All
            else selected = sender:GetText() end
			button:SetText(selected)
			print( "Selected "..selected )
			if button.Action then
				button:Action(selected)
			end
        end
        menuItems:Add( Item )
	end
	return Menu
end

function RR_Window:Constructor()
	Turbine.UI.Lotro.Window.Constructor( self )

	-- Position the window near the top and to left of center of the screen.
	self:SetSize( 320,235 )
	pos = { x=Turbine.UI.Display.GetWidth()/6, y=Turbine.UI.Display.GetHeight()/4 }
	self:SetPosition( pos.x, pos.y )
	self:SetText( "Reputation Reference" )

	-- Create a Factions button
	self.zonesButton = self:AddField(Button, "List Factions", {x=90,y=40}, {x=120,y=20} )
	self.zonesButton.Click = function( sender,args )
        RR_Command:Execute("rr","factions")
	end

	-- Create a label and add it to the window.
	self:AddField(Label, "Faction:", {x=30,y=70}, {x=60,y=16} )

	-- Create a Faction menu button
	self.factionMenu = self:AddField(Button, All, {x=90,y=68}, {x=195,y=20} )
	self.factionMenu.Click = function( sender,args )
		local Menu = RR_Window:BuildMenu(FactList,self.factionMenu)
		local x,y = self.factionMenu:PointToScreen(0,20)
		Menu:ShowMenuAt(x,y)
	end
--	self.factionMenu.Action = function( sender,args )
--		self.locationMenu:SetText( "" )
--	end

	-- Create a Faction Details button
	self.fdButton = self:AddField(Button, "Faction Details", {x=30,y=95}, {x=130,y=20} )
	self.fdButton.Click = function( sender,args )
        local name = self.factionMenu:GetText()
		if name=="" then print("Select a faction.")
        else RR_Command:Execute("rr",FactName[name]) end
	end

	-- Create an Vendor Items button
	self.viButton = self:AddField(Button, "Vendor Items", {x=170,y=95}, {x=115,y=20} )
	self.viButton.Click = function( sender,args )
        local name = self.factionMenu:GetText()
		if name==All then print("Select a faction.")
        else RR_Command:Execute("rrv",FactName[name],self.level:GetText()) end
	end

	-- Create a label and add it to the window.
	self:AddField(Label, "Vendor item types:", {x=25,y=125}, {x=135,y=16} )

	-- Create a Group Types menu button
	self.typesMenu = self:AddField(Button, All, {x=30,y=145}, {x=110,y=20} )
	self.typesMenu.Click = function( sender,args )
		local Menu = RR_Window:BuildMenu(GroupList,self.typesMenu)
		local x,y = self.typesMenu:PointToScreen(-5,20)
		Menu:ShowMenuAt(x,y)
	end
	self.typesMenu.Action = function( sender,args )
		self.subMenu:SetText(All)
		Select = args
	end

	-- Create a sub-Types menu button
	self.subMenu = self:AddField(Button, "", {x=150,y=145}, {x=125,y=20} )
	self.subMenu.Click = function( sender,args )
        local group = self.typesMenu:GetText()
		if group==SelType then print("Select a type.") return end
		local tbl = ItemCode[ItemType[group]]
		if type(tbl)~="table" then print("No sub-type.") return end
		local list = { All }
		for s,name in pairs(tbl) do
			if s~="" then table.insert(list,name) end
		end
		table.sort(list)
		local Menu = RR_Window:BuildMenu(list,self.subMenu)
		local x,y = self.subMenu:PointToScreen(-5,20)
		Menu:ShowMenuAt(x,y)
	end
	self.subMenu.Action = function( sender,args )
		Select = args
	end

	-- Create an Types button
	self.hornsButton = self:AddField(Button, "List Types", {x=50,y=170}, {x=90,y=20} )
	self.hornsButton.Click = function( sender,args )
        RR_Command:Execute("rrv","types")
	end

	-- Create an Find Items button
	self.hornsButton = self:AddField(Button, "Find Items", {x=150,y=170}, {x=95,y=20} )
	self.hornsButton.Click = function( sender,args )
		if Select==All then print("Select a type.") return end
        RR_Command:Execute("rrv", Select, self.level:GetText())
	end

	-- Create a label and add it to the window.
	self:AddField(Label, "Max level:", {x=65,y=195}, {x=75,y=16} )

	-- Create a text field and add it to the window.
	self.level = self:AddField(TextBox, '', {x=136,y=197}, {x=24,y=15} )

end

RRW_Command = Turbine.ShellCommand()
local help_text = "rrw (open RR window)"
function RRW_Command:GetShortHelp() return "rrw (RR window commands)" end
function RRW_Command:GetHelp() return help_text end

function RRW_Command:Execute( command,args )
    RR_window:SetVisible( true )
end

Turbine.Shell.AddCommand( "rrw",RRW_Command )
